<template>
  <section class="mywalletContent">
    <header class="mywalletHeader">我的钱包</header>
    <ul class="card_container">
      <li>
        <div class="img_box">
          <img :src="walletIcon" />
        </div>
        <div class="card_info">
          <span class="title">账户总额(元)</span>
          <el-tooltip class="box-item" effect="dark" content="账户总额=可用余额" placement="top">
            <img :src="tipsicon">
          </el-tooltip>
          <p class="point">{{ formTotal.totalAmount }}</p>
        </div>
        <div class="card_other">
          <el-button type="primary" size="mini" @click="RechargeBtn">充值</el-button>
        </div>
      </li>

      <li>
        <div class="img_box">
          <img :src="walletIcon" />
        </div>
        <div class="card_info">
          <span class="title">可用余额(元)</span>
          <el-tooltip class="box-item" effect="dark" content="可以直接被消费使用、转账、提现的金额。" placement="top">
            <img :src="tipsicon">
          </el-tooltip>
          <p class="point">{{ formTotal.availableAmount }}</p>
        </div>
        <div class="card_other">
          <el-button size="mini" @click="WithdrawalBtn">提现</el-button>
        </div>
      </li>

      <li>
        <div class="img_box">
          <img :src="walletIcon" />
        </div>
        <div class="card_info">
          <span class="title">冻结金额(元)</span>
          <el-tooltip class="box-item" effect="dark" content="因业务关系，暂时被冻结的金额，待业务关系解除后则会转入可用余额。" placement="top">
            <img :src="tipsicon">
          </el-tooltip>
          <p class="point">{{ formTotal.frozenAmount }}</p>
        </div>
        <div class="card_other">
        </div>
      </li>
    </ul>
    <ol class="info_container">
      <li>
        <div class="left_content">
          <span>账户名:</span>
        </div>
        <div class="right_content">
          <span>{{ form.comName }}</span>
        </div>
      </li>
      <li>
        <div class="left_content">
          <span>钱包账户号:</span>
        </div>
        <div class="right_content">
          <span>{{ form.walletAccountNo }}</span>
        </div>
      </li>
      <li>
        <div class="left_content">
          <span>账户状态:</span>
        </div>
        <div class="right_content">
          <span>{{ form.acctStat == 'N' ? '正常' : form.acctStat == 'C' ? '关闭' : form.acctStat == 'F' ? '冻结' : form.acctStat
            == 'D' ? '销户' : '' }}</span>
          <el-link type="primary" class="editclass" @click="accountStep">修改</el-link>
        </div>
      </li>
      <li>
        <div class="left_content">
          <span>手机号:</span>
        </div>
        <div class="right_content">
          <span>{{ form.contactPhone }}</span>
        </div>
      </li>
      <li>
        <div class="left_content">
          <span>绑定银行账户:</span>
        </div>
        <div class="right_content">
          <span>{{ form.cardNo }}</span>
        </div>
      </li>
      <li>
        <div class="left_content">
          <span>开户时间:</span>
        </div>
        <div class="right_content">
          <span>{{ form.createTime }}</span>
        </div>
      </li>
      <li>
        <div class="left_content">
          <span>银行卡状态:</span>
        </div>
        <div class="right_content">
          <span>{{ form.tokenNo ? '正常' : '失败' }}</span>
          <el-link type="primary" class="editclass" @click="bankStep">修改</el-link>
        </div>
      </li>
    </ol>
    <div class="txttips">查看<a href="https://bcxinstatic.bktang.cn/thirdparty/payagreement.pdf"
        target="_blank">支付服务协议</a>及<a href="https://bcxinstatic.bktang.cn/thirdparty/useragreement.pdf"
        target="_blank">用户服务协议</a>
    </div>
    <!-- 充值弹窗 -->
    <RechargeDialog ref="configDialogRef" @refresh="refresh"></RechargeDialog>
    <!-- 钱包提现 -->
    <WithdrawalDialog ref="configDialogWithRef" @refresh="refresh"></WithdrawalDialog>
  </section>
</template>
<script lang="ts" setup>
import { onMounted, reactive, ref, nextTick, computed } from 'vue'
import walletIcon from '/@/assets/walletIcon.png'
import tipsicon from '/@/assets/tipsicon.png'
import RechargeDialog from './RechargeDialog.vue'
import WithdrawalDialog from './WithdrawalDialog.vue'
import { ConfigApi } from '/@/api/api'
// 定义变量
const configDialogRef = ref();
const configDialogWithRef = ref();
let form = ref({})
let formTotal = ref({})
// 定义子组件向父组件传值/事件
const emit = defineEmits(['accountStep', 'bankStep']);
//跳转到账户页面
const accountStep = () => {
  emit('accountStep', true)
}
//跳转到银行绑定页面
const bankStep = () => {
  emit('bankStep', true)
}
//充值弹窗
const RechargeBtn = () => {
  configDialogRef.value.openDialog(form.value.walletAccountNo)
}
//提现弹窗
const WithdrawalBtn = () => {
  configDialogWithRef.value.openDialog(form.value.walletAccountNo, form.value.contactPhone)
}
//获取企业钱包账户信息
const getWalletAccount = () => {
  ConfigApi().getWalletAccountaApi().then(res => {
    console.log('res11', res)
    form.value = res.data
  })
}
//获取企业钱包账户金额
const getwalletAccountAmount = () => {
  ConfigApi().getwalletAccountAmountApi().then(res => {
    console.log('res22', res.data)
    formTotal.value = res.data
    console.log('formTotal', formTotal)
  })
}
//刷新页面
const refresh = () => {
  getWalletAccount()
  getwalletAccountAmount()
}
onMounted(() => {
  getWalletAccount()
  getwalletAccountAmount()
})
</script>
<style lang="scss" scoped>
.mywalletContent {
  display: flex;
  flex-direction: column;
  align-items: center;

  .mywalletHeader {
    border-bottom: 1px solid #e8e8e8;
    padding: 10px 0;
    text-align: left;
    width: 100%;
    text-indent: 20px;
    font-weight: bold;
    font-size: 14px;
  }

  .card_container {
    width: 90%;
    min-width: 800px;
    min-height: 120px;
    padding-left: 0;
    display: flex;
    align-items: center;
    border: 1px solid #ddd;
    border-radius: 4px;
    list-style: none;
    margin-top: 20px;

    li {
      width: 100%;
      height: 100%;
      flex-grow: 1;
      list-style: none;
      border-left: 1px solid #ddd;
      display: flex;
      align-items: center;
      padding: 12px;

      .img_box {
        width: 80px;
        flex-shrink: 0;
        border-radius: 50%;
        overflow: hidden;
        display: flex;
        justify-content: center;
      }

      .card_info {
        height: 100%;
        margin-left: 10px;
        flex: 1;

        .title {
          margin-right: 10px;
        }

        .point {
          font-size: 20px;
          font-weight: bold;
        }
      }

      .card_other {
        align-self: flex-start;
        display: flex;
        justify-content: flex-end;
      }
    }
  }

  .info_container {
    display: flex;
    flex-direction: column;
    text-align: left;
    width: 90%;
    margin-top: 50px;
    color: rgba(0, 0, 0, .65);

    li {
      display: flex;
      align-items: center;
      padding: 15px 0;

      .left_content {
        width: 100px;
        justify-content: flex-end;
        display: flex;
      }

      .right_content {
        margin-left: 40px;
        min-width: 260px;
        display: flex;
        align-items: center;

        .editclass {
          margin-left: 30px;
        }
      }
    }
  }

  .txttips {
    font-size: 14px;
    color: rgba(0, 0, 0, 0.9);
    display: flex;
    width: 100%;
    justify-content: center;
    text-align: center;
    margin: 0 auto;
    margin-top: 200px;

    a {
      color: #1890ff;
    }
  }


}
</style>